<?php

namespace Opencart\Catalog\Controller\Extension\Qazaqpay\Payment;
class Qazaqpay extends \Opencart\System\Engine\Controller {
	/**
	 * @return string
	 */
	public function index(): string {
		$this->load->language('extension/qazaqpay/payment/qazaqpay');

		$data['language'] = $this->config->get('config_language');

		$this->getGatewayAuthToken();

		return $this->load->view('extension/qazaqpay/payment/qazaqpay', $data);
	}

	/**
	 * @return void
	 */
	public function confirm(): void {
		$this->load->language('extension/qazaqpay/payment/qazaqpay');

		$json = [];

		if (!isset($this->session->data['order_id'])) {
			$json['error'] = $this->language->get('error_order');
		}

		if (!isset($this->session->data['payment_method']) || $this->session->data['payment_method']['code'] != 'qazaqpay.qazaqpay') {
			$json['error'] = $this->language->get('error_payment_method');
		}

		if (!$json) {
			$token = $this->getGatewayAuthToken();
			if (!$token) {
				$json['error']['warning'] = $this->language->get('error_gateway');
			}
			if ($token) {
				$redirect = $this->initPayment($token);
				if (!$redirect) {
					$json['error']['warning'] = $this->language->get('error_gateway');
				}
			}
		}

		if (!$json) {
			$this->load->model('checkout/order');

			// $this->model_checkout_order->addHistory($this->session->data['order_id'], $this->config->get('payment_qazaqpay_order_status_id'));

			// $json['redirect'] = $this->url->link('checkout/success', 'language=' . $this->config->get('config_language'), true);
			$json['redirect'] = $redirect;
		}

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}

	public function getGatewayAuthToken() {
		$this->load->model('checkout/order');

		$body = json_encode(array(
			'login' => $this->config->get('payment_qazaqpay_gateway_login'),
			'password' => $this->config->get('payment_qazaqpay_gateway_password')
		), true);

		$ctp_url = $this->config->get('payment_qazaqpay_gateway_address') . '/api/auth/login';

		$curl = curl_init($ctp_url);
		curl_setopt($curl, CURLOPT_HEADER, 0);
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($curl, CURLOPT_HTTPHEADER, array( 'Content-Type: application/json' ));
		curl_setopt($curl, CURLOPT_FORBID_REUSE, 1);
		curl_setopt($curl, CURLOPT_FRESH_CONNECT, 1);
		curl_setopt($curl, CURLOPT_POST, 1);
		curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
	
		$response = curl_exec($curl);
		$curl_error = curl_error($curl);
		$curl_errno = curl_errno($curl);
		curl_close($curl);

		if (!$response) {
			$this->log->write("Qazaqpay token request failed: $curl_error ($curl_errno)");
			return "";
		}

		$data = json_decode($response,true);

		if (!isset($data["token"])) {
			$this->log->write("Qazaqpay token request failed: $data");
			return "";
		}

		return $data["token"];
	}

	public function initPayment($token) {
		$order = $this->model_checkout_order->getOrder($this->session->data['order_id']);
		$amount = (float) $this->currency->format($order['total'], $order['currency_code'], $order['currency_value'], false);
		
		$success_url = $this->url->link('checkout/success', 'language=' . $this->config->get('config_language'), true);
		$error_url = $this->url->link('checkout/checkout', 'language=' . $this->config->get('config_language'), true);
		$webhook_url = $this->url->link('extension/qazaqpay/payment/qazaqpay.webhook', '');

		$body = array(
            "virtual_pos_id" => intval($this->config->get('payment_qazaqpay_gateway_virtual_pos_id')),
            "agent_id" => intval($this->config->get('payment_qazaqpay_gateway_agent_id')),
            "success_url" => $success_url,
            "error_url" => $error_url,
            "notify_url" => $success_url,
            "webhook_url" => $webhook_url,
            "client_info" => array(
                "full_name" => $order['firstname'] . ' ' . $order['lastname'],
            ),
            "bill" => array(
                "bill_id" => $this->session->data['order_id'],
                "sum" => $amount,
                "currency" => "KZT",
                "claims" => array(
                    array(
                      "claim_id" => $this->session->data['order_id'],
                      "sum" => $amount,
                      "payment_type_id" => intval($this->config->get('payment_qazaqpay_gateway_payment_type_id')),
                    )
                )
            )
          );

		$ctp_url = $this->config->get('payment_qazaqpay_gateway_address') . '/api/banks/call_payment_page';

		$curl = curl_init($ctp_url);
		curl_setopt($curl, CURLOPT_HEADER, 0);
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($curl, CURLOPT_HTTPHEADER, array(
			'Content-Type: application/json',
			'Authorization: Bearer ' . $token
		));
		curl_setopt($curl, CURLOPT_FORBID_REUSE, 1);
		curl_setopt($curl, CURLOPT_FRESH_CONNECT, 1);
		curl_setopt($curl, CURLOPT_POST, 1);
		curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode( $body, true ));
	
		$response = curl_exec($curl);
		$curl_error = curl_error($curl);
		$curl_errno = curl_errno($curl);
		curl_close($curl);

		if (!$response) {
			$this->log->write("Qazaqpay init payment request failed: $curl_error ($curl_errno)");
			return "";
		}

		$data = json_decode($response,true);

		if (!isset($data["url"])) {
			$this->log->write("Qazaqpay init payment request failed: $response");
			return "";
		}

		return $data["url"];
	}

	public function webhook() {
		$input = (string) file_get_contents("php://input");
		$data = json_decode($input, true);

		if (!isset($data["billId"])) {
			return;
		}

		$this->log->write("Webhook received: $input");

		$this->load->model('checkout/order');
		$order_id = $data["billId"];
		$order = $this->model_checkout_order->getOrder($order_id);

		if ($order) {
			$this->model_checkout_order->addHistory($order_id, $this->config->get('payment_qazaqpay_order_status_id'));
		}
	}
}
